#
# spec file for package libiio
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           libiio
Version:        0.11
Release:        2.1
%define so_ver  0
Url:            https://wiki.analog.com/resources/tools-software/linux-software/libiio
Summary:        Industrial I/O tools
License:        LGPL-2.1+
Group:          System/Libraries
Source:         https://github.com/analogdevicesinc/libiio/archive/v%{version}.tar.gz#/libiio-%{version}.tar.gz
BuildRequires:  bison
BuildRequires:  cmake
BuildRequires:  flex
BuildRequires:  libxml2-devel
BuildRequires:  python3-devel
BuildRequires:  systemd-rpm-macros
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%{?systemd_requires}

%description
Library for industrial I/O.

%package -n libiio%{so_ver}
Summary:        Industrial I/O library
Group:          System/Libraries

%description -n libiio%{so_ver}
Library for industrial I/O.

%package devel
Summary:        Industrial I/O library -- development files
Group:          Development/Libraries/C and C++
Requires:       libiio%{so_ver} = %{version}-%{release}
Recommends:     libiio = %{version}-%{release}

%description devel
Library for industrial I/O.

This sub-package contains the development files.

%package python
Summary:        Industrial I/O library -- Python bindings
Group:          System/Libraries

%description python
Library for industrial I/O.

This sub-package contains the Python bindings.

%package daemon
Summary:        Industrial I/O library -- iiod
Group:          System/Libraries

%description daemon
Library for industrial I/O.

This sub-package contains the iiod daemon.

%prep
%setup -q

%build
%cmake \
  -DPYTHON_EXECUTABLE=/usr/bin/python3
%make_jobs

%install
%cmake_install
install -D -m 444 iiod/init/iiod.service %{buildroot}%{_unitdir}/iiod.service

%check
%ctest

%post -n libiio%{so_ver} -p /sbin/ldconfig

%postun -n libiio%{so_ver} -p /sbin/ldconfig

%pre daemon
%service_add_pre iiod.service

%post daemon
%service_add_post iiod.service

%preun daemon
%service_del_preun iiod.service

%postun daemon
%service_del_postun iiod.service

%files
%defattr(-,root,root,-)
%doc COPYING.txt README.md
%{_bindir}/iio_adi_xflow_check
%{_bindir}/iio_attr
%{_bindir}/iio_genxml
%{_bindir}/iio_info
%{_bindir}/iio_readdev
%{_bindir}/iio_reg

%files -n libiio%{so_ver}
%defattr(-,root,root,-)
%{_libdir}/libiio.so.%{so_ver}*

%files -n libiio-devel
%defattr(-,root,root,-)
%{_includedir}/iio.h
%{_libdir}/libiio.so
%{_libdir}/pkgconfig/libiio.pc

%files python
%defattr(-,root,root,-)
%{python3_sitelib}/*

%files daemon
%defattr(-,root,root,-)
%{_sbindir}/iiod
%{_unitdir}/iiod.service

%changelog
* Wed Jan 17 2018 mardnh@gmx.de
- Force usage of python3
* Tue Dec  5 2017 wk@ire.pw.edu.pl
- Update to version 0.11:
  * Lots of bug fixes
  * Add 'ip,ip-addr' context attribute to network contexts
  * Better handling of communication timeouts on Windows
  * IIOD can now stream much faster, up to the link's speed
  * Fix USB backend and IIOD not handling huge buffers
  * Channels are now disabled when a iio_buffer is destroyed
  * Libiio/IIOD can now handle channels that share their index
  * Add 'iio_attr' tool to read/write device/channel attributes
* Mon Jul 24 2017 mardnh@gmx.de
- Update to version 0.10:
  * Lots of bug fixes
  * Add 'ip,ip-addr' context attribute to network contexts
  * Better handling of communication timeouts on Windows
  * IIOD can now stream much faster, up to the link's speed
  * Fix USB backend and IIOD not handling huge buffers
  * Channels are now disabled when a iio_buffer is destroyed
  * Libiio/IIOD can now handle channels that share their index
  * Add 'iio_attr' tool to read/write device/channel attributes
* Tue May 23 2017 stefan.bruens@rwth-aachen.de
- Update to v0.9 - Changelog:
  * Introduced context attributes
  * Add API for querying the list of enabled backends
  * IIOD can now serve over USB (using FunctionFS)
  * Fix occasional buffer drops in IIOD
  * Python bindings are now compatible with Python 3
  * Add support for scanning in Python bindings
  * Fix USB backend on Windows >= 8.1
  * Add auto context creation in iio_readdev/iio_info
  * Lots, lots of bug fixes
- Update to v0.8 - no changelog provided
- drop libiio_systemd.patch, taken from upstream
* Sun Oct 30 2016 afaerber@suse.de
- Initial (v0.7)
